@@ -27,6 +27,7 @@ class DataManager:
         self.id_map = {}
         self.activated_data = OrderedDict()
         self.activated_group = {}
+        self.is_activated_data_rules_contains_request_data = False
         self.LEVEL_SUPER_ACTIVATED = 3
         self.clipboard = None
         self.save_to_group_id = None
@@ -37,8 +38,10 @@ class DataManager:
         self.root = self.get_default_root()
         self._snapshot_workspace = None
 
-        self.add_group_ignore_keys = ['id', 'type', 'children']
-        self.update_group_ignore_keys = ['id', 'parent_id', 'type', 'children']
+        self.add_group_ignore_keys = set(['id', 'type', 'children'])
+        self.update_group_ignore_keys = set(['id', 'parent_id', 'type', 'children'])
+
+        self.unsave_keys = set()
 
         self.DELETE_STEP = 100
         self.is_deleting_lock = False
@@ -74,11 +77,31 @@ class DataManager:
 
     def reload(self):
         self._adapter._reload()
+        self.add_parent_into_node()
+        self.add_super_by()
+
+    def add_parent_into_node(self):
         for node in self.id_map.values():
             node.update({
                 'parent': self._get_abs_parent_obj(node),
                 'abs_parent_path': self._get_abs_parent_path(node)
             })
+        self.unsave_keys.update(['parent', 'abs_parent_path'])
+
+    def add_super_by(self):
+        for node in self.id_map.values():
+            if not node.get('super_id'):
+                continue
+            super_parent_node = self.id_map.get(node['super_id'])
+            if not super_parent_node:
+                continue
+            if not super_parent_node.get('super_by'):
+                super_parent_node['super_by'] = []
+            super_parent_node['super_by'].append({
+                'id': node['id'],
+                'name': node['name']
+            })
+        self.unsave_keys.add('super_by')
 
     def get(self, _id):
         """
@@ -162,6 +185,19 @@ class DataManager:
         data_map = {d['id']: d for d in data_list}
         self.activated_data.update({i: data_map[i] for i in ordered_data_id if data_map.get(i)})
         self.activated_group[_id] = _node
+        self._check_activated_data_rules_contains_request_data()
+    
+    def _check_activated_data_rules_contains_request_data(self):
+        self.is_activated_data_rules_contains_request_data = False
+        for _data_id in self.activated_data:
+            _data = self.activated_data[_data_id]
+            rules = _data.get('rule')
+            if not rules:
+                continue
+            for rule_key in rules.keys():
+                if rule_key.startswith('request.data'):
+                    self.is_activated_data_rules_contains_request_data = True
+                    return 
 
     def _collect_activate_node(self, node, level_lefted=1):
         id_list = [node['id']]
@@ -196,6 +232,7 @@ class DataManager:
         """
         self.activated_data = OrderedDict()
         self.activated_group = {}
+        self._check_activated_data_rules_contains_request_data()
 
     def reactive(self):
         for _group_id in self.activated_group:
@@ -205,10 +242,15 @@ class DataManager:
         """
         Find matched mock data from activated data
         """
+        if self.is_activated_data_rules_contains_request_data:
+            decode_flow = {}
+            application.encoders_decoders.decoder_handler(flow, output=decode_flow)
+        else:
+            decode_flow = flow
         _matched_data = []
         for _data_id in self.activated_data:
             _data = self.activated_data[_data_id]
-            if self._is_match_rule(flow, _data.get('rule')):
+            if self._is_match_rule(decode_flow, _data.get('rule')):
                 _matched_data.append(_data)
                 break
 
@@ -356,7 +398,8 @@ class DataManager:
         return json.dumps(data, ensure_ascii=False)
 
     def add_group(self, data):
-        new_group = {k: data[k] for k in data if k not in self.add_group_ignore_keys}
+        ignore_key = self.add_group_ignore_keys | self.unsave_keys
+        new_group = {k: data[k] for k in data if k not in ignore_key}
 
         parent_id = data.get('parent_id')
         if parent_id == None:
@@ -656,9 +699,15 @@ class DataManager:
         if not node:
             raise IDNotFound(_id)
 
+        # Remove unsave_key add by DataManager itself
+        for key in self.unsave_keys:
+            data.pop(key) if key in data else None
+
+        # Add new key into node
         update_data = {k: data[k] for k in data if k not in self.update_group_ignore_keys}
         node.update(update_data)
 
+        # Remove deleted key in node
         delete_keys = [k for k in node if k not in data and k not in self.update_group_ignore_keys]
         for key in delete_keys:
             node.pop(key)
